#!/bin/bash

# After running of ./upstream-collect.sh, this script will update FTP.

set -o errexit

OSC_PACKAGE_DIR=/home/sbrabec/OSCI/home:sbrabec:branches:SUSE:SLE-12:GA:proposed-translation-fixes/translation-update-upstream
FTP_MIRROR_DIR=/home/sbrabec/local/ftp.suse.com/pub/people/sbrabec/translation-update-upstream
BRANCH=SLE12
API=https://api.suse.de
PROJECT=home:sbrabec:branches:SUSE:SLE-12:GA:proposed-translation-fixes

cd "$OSC_PACKAGE_DIR"

RPM_NAME=$(sed -n 's/^Name: *//p' <translation-update-upstream.spec)
RPM_VERSION=$(sed -n 's/^Version: *//p' <translation-update-upstream.spec)

rm -rf "$FTP_MIRROR_DIR/$BRANCH"
mkdir -p "$FTP_MIRROR_DIR/$BRANCH/generated-outputs" "$FTP_MIRROR_DIR/$BRANCH/statistics"

echo "Copying sources..."
for SOURCE in $(sed -n "s/%{name}/$RPM_NAME/g;s/%{version}/$RPM_VERSION/g;s/^\\(Source\\|Patch\\)[0-9]*: *//p" <translation-update-upstream.spec) ; do
	cp -a $SOURCE "$FTP_MIRROR_DIR/$BRANCH/"
done
echo "Rest of sources..."
cp -a translation-update-upstream.{spec,changes} "$FTP_MIRROR_DIR/$BRANCH/"

for DIR in po* gnome-patch-translation ; do
	echo "Creating $DIR.tar.bz2..."
	tar -jcf "$FTP_MIRROR_DIR/$BRANCH/generated-outputs/$DIR.tar.bz2" $DIR
	touch -r $DIR "$FTP_MIRROR_DIR/$BRANCH/generated-outputs/$DIR.tar.bz2"
done
echo "Rest of generated files..."
cp -a translation-update-from-* gnome-patch-translation.lst upstream-collect.{domain-map,log} "$FTP_MIRROR_DIR/$BRANCH/generated-outputs/"

echo "Sources..."
mkdir "$FTP_MIRROR_DIR/$BRANCH/proposed-translation-fixes"
for PKG in $(osc -A "$API" ls "$PROJECT") ; do
	osc -A "$API" ldiff "$PROJECT" "$PKG" >"$FTP_MIRROR_DIR/$BRANCH/proposed-translation-fixes/$PKG.patch"
	for FILE in $(sed -n "s/^Binary files \([^ ]*\) .* differ/\1/p" <"$FTP_MIRROR_DIR/$BRANCH/proposed-translation-fixes/$PKG.patch") ; do
		mkdir -p "$FTP_MIRROR_DIR/$BRANCH/proposed-translation-fixes/$PKG"
		osc -A "$API" cat "$PROJECT" "$PKG" "$FILE" >"$FTP_MIRROR_DIR/$BRANCH/proposed-translation-fixes/$PKG/$FILE"
	done
done
rm -f "$FTP_MIRROR_DIR/$BRANCH/proposed-translation-fixes/translation-update-upstream.patch" "$FTP_MIRROR_DIR/$BRANCH/proposed-translation-fixes/translation-update.patch"

echo "Statistics..."
cp -a check-translation-completeness.zip "$FTP_MIRROR_DIR/$BRANCH/statistics/"

touch -r . "$FTP_MIRROR_DIR/$BRANCH" "$FTP_MIRROR_DIR/$BRANCH/generated-outputs"
touch -r . "$FTP_MIRROR_DIR/$BRANCH" "$FTP_MIRROR_DIR/$BRANCH/statistics"

echo "Done!"
